==> sanctify-1.0.0.tar.gz: sanctify-1.0.0/sanctify/utils.py <==
from datetime import date

from dateutil.relativedelta import relativedelta
from loguru import logger

from sanctify.constants import ComparisonOperations


def replace_dict_keys(original_dict: dict, key_mapping: dict) -> dict:
    """
    Replace keys in a dictionary with the corresponding values from a key mapping dictionary.

    Args:
        original_dict (dict): Original dictionary.
        key_mapping (dict): Dictionary mapping old keys to new keys.

    Returns:
        dict: Dictionary with replaced keys.
    """
    return {key_mapping.get(key, key): value for key, value in original_dict.items()}


def match_comparision_operation(
    value, operation: str, operand: str | int
) -> bool | NotImplementedError | Exception | ValueError:
    """
    Perform a comparison operation between a value and an operand based on the specified operation.

    Args:
        value: Value to compare.
        operation (str): Comparison operation.
        operand (str|int): Operand for comparison.

    Returns:
        bool: Result of the comparison.

    Raises:
        NotImplementedError: If the operation is not supported.
        TypeError: If the comparison fails due to a type mismatch.
        Exception: If an unexpected exception occurs.
        ValueError: If the operation or operand is invalid.
    """
    err_message = f"{operation = } with {operand = } | DEBUG: {type(value) = }, {value = }"
    try:
        # Perform the comparison operation based on the provided operation
        comparison_mapping = {
            ComparisonOperations.LESS_THAN.value: lambda x, y: x < y,
            ComparisonOperations.LESS_THAN_OPERATOR.value: lambda x, y: x < y,
            ComparisonOperations.LESS_THAN_EQUALS.value: lambda x, y: x <= y,
            ComparisonOperations.LESS_THAN_EQUALS_OPERATOR.value: lambda x, y: x <= y,
            ComparisonOperations.GREATER_THAN.value: lambda x, y: x > y,
            ComparisonOperations.GREATER_THAN_OPERATOR.value: lambda x, y: x > y,
            ComparisonOperations.GREATER_THAN_EQUALS.value: lambda x, y: x >= y,
            ComparisonOperations.GREATER_THAN_EQUALS_OPERATOR.value: lambda x, y: x >= y,
            ComparisonOperations.EQUALS.value: lambda x, y: x == y,
            ComparisonOperations.EQUALS_OPERATOR.value: lambda x, y: x == y,
            ComparisonOperations.NOT_EQUALS.value: lambda x, y: x != y,
            ComparisonOperations.NOT_EQUALS_OPERATOR.value: lambda x, y: x != y,
        }
        if operation in comparison_mapping:
            return comparison_mapping[operation](value, operand)
        else:
            raise NotImplementedError(f"Unsupported: {err_message}")

    except TypeError as err:
        err = TypeError(f"Comparison Failed: {err_message}")
        logger.error(f"{str(err) = }")
        raise err


def calculate_age(date_of_birth: date, current_date: date = date.today()) -> int:
    """
    Calculate the age based on the date of birth.

    Args:
        date_of_birth (date): Date of birth.

    Returns:
        int: Calculated age.

    Notes:
        The age is calculated by subtracting the birth year from the current year,
        and adjusting for the birth month and day.

    Example:
        If the date of birth is '1990-05-15', and the current date is '2022-08-10',
        the calculated age will be 32.
    """
    return relativedelta(current_date, date_of_birth).years

==> sanctify-1.0.2.tar.gz: sanctify-1.0.2/sanctify/utils.py <==
from datetime import date

from dateutil.relativedelta import relativedelta
from loguru import logger

from sanctify.constants import ComparisonOperations


def replace_dict_keys(original_dict: dict, key_mapping: dict) -> dict:
    """
    Replace keys in a dictionary with the corresponding values from a key mapping dictionary.

    Args:
        original_dict (dict): Original dictionary.
        key_mapping (dict): Dictionary mapping old keys to new keys.

    Returns:
        dict: Dictionary with replaced keys.
    """
    return {key_mapping.get(key, key): value for key, value in original_dict.items()}


def match_comparision_operation(
    value, operation: str, operand: str | int
) -> bool | NotImplementedError | Exception | ValueError:
    """
    Perform a comparison operation between a value and an operand based on the specified operation.

    Args:
        value: Value to compare.
        operation (str): Comparison operation.
        operand (str|int): Operand for comparison.

    Returns:
        bool: Result of the comparison.

    Raises:
        NotImplementedError: If the operation is not supported.
        TypeError: If the comparison fails due to a type mismatch.
        Exception: If an unexpected exception occurs.
        ValueError: If the operation or operand is invalid.
    """
    err_message = f"{operation = } with {operand = } | DEBUG: {type(value) = }, {value = }"
    try:
        # Perform the comparison operation based on the provided operation
        comparison_mapping = {
            ComparisonOperations.LESS_THAN.value: lambda x, y: x < y,
            ComparisonOperations.LESS_THAN_OPERATOR.value: lambda x, y: x < y,
            ComparisonOperations.LESS_THAN_EQUALS.value: lambda x, y: x <= y,
            ComparisonOperations.LESS_THAN_EQUALS_OPERATOR.value: lambda x, y: x <= y,
            ComparisonOperations.GREATER_THAN.value: lambda x, y: x > y,
            ComparisonOperations.GREATER_THAN_OPERATOR.value: lambda x, y: x > y,
            ComparisonOperations.GREATER_THAN_EQUALS.value: lambda x, y: x >= y,
            ComparisonOperations.GREATER_THAN_EQUALS_OPERATOR.value: lambda x, y: x >= y,
            ComparisonOperations.EQUALS.value: lambda x, y: x == y,
            ComparisonOperations.EQUALS_OPERATOR.value: lambda x, y: x == y,
            ComparisonOperations.NOT_EQUALS.value: lambda x, y: x != y,
            ComparisonOperations.NOT_EQUALS_OPERATOR.value: lambda x, y: x != y,
        }
        if operation in comparison_mapping:
            return comparison_mapping[operation](value, operand)
        else:
            raise NotImplementedError(f"Unsupported Comparision: {err_message}")

    except TypeError as err:
        err = TypeError(f"System Error: {err_message}")
        logger.error(f"{str(err) = }")
        raise err


def calculate_age(date_of_birth: date, current_date: date = date.today()) -> int:
    """
    Calculate the age based on the date of birth.

    Args:
        date_of_birth (date): Date of birth.

    Returns:
        int: Calculated age.

    Notes:
        The age is calculated by subtracting the birth year from the current year,
        and adjusting for the birth month and day.

    Example:
        If the date of birth is '1990-05-15', and the current date is '2022-08-10',
        the calculated age will be 32.
    """
    return relativedelta(current_date, date_of_birth).years
